@@ -1,8 +1,9 @@
 .onLoad <- function(lib, pkg){
- packageStartupMessage("\n")
+
+  packageStartupMessage("\n")
   packageStartupMessage("######################################################################################\n")
   packageStartupMessage("Easy Microarray Analysis\n")
   packageStartupMessage("EMA stable version\n")
-  packageStartupMessage("Current release : v1.2 - 10/01/10\n")
+  packageStartupMessage("Current release : v1.3.1 - 09/06/11\n")
   packageStartupMessage("######################################################################################\n")    
 }
